@@ -16,13 +16,87 @@
 # along with this module; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 package Haver::Server;
-
-#use 5.008002;
 use strict;
 use warnings;
 
-our $VERSION = 0.03;
+our $Registry;
+BEGIN {
+	use Exporter;
+	use base 'Exporter';
 
+	our $VERSION = 0.04;
+	our @EXPORT = ();
+	our @EXPORT_OK = qw( $Registry );
+}
+
+use IO::Poll;
+use POE;
+use Haver::Server::Listener;
+use Haver::Server::Registry;
+use Haver::Server::Channel;
+use Haver::Server::User;
+
+use Haver::Utils::Logger;
+use Haver::Protocol::Errors;
+
+use Devel::Size qw(total_size);
+
+
+sub boot {
+	my ($this, %opts) = @_;
+	$|++;
+
+	Haver::Protocol::Errors->server_mode();
+	$Registry = instance Haver::Server::Registry;
+
+	$Haver::Server::Object::DataDir = $opts{confdir};
+	$Registry->load();
+
+	$this->create(%opts);
+	$poe_kernel->run();
+}
+sub create {
+	my ($class, %opts) = @_;
+	POE::Session->create(
+		package_states => 
+		[
+			$class => [
+				'_start',
+				'_stop',
+				'interrupt',
+				'die',
+				'shutdown',
+			]
+		],
+		heap => \%opts,
+	);
+}
+
+sub _start {
+	my ($kernel, $heap) = @_[KERNEL, HEAP];
+	my $port = $heap->{port} || $Registry->get_field('ServerPort');
+	
+	print "Server starts.\n";
+	create Haver::Utils::Logger    (logfile => $heap->{logfile});
+	create Haver::Server::Listener (port => $port);
+
+	$kernel->sig('INT' => 'intterrupt');
+	$kernel->sig('DIE' => 'die');
+}
+sub _stop {
+	print "Server stops.\n";
+	print "Total size of registry: ", total_size($Registry), "\n";
+	$Registry->save($_[HEAP]{confdir});
+}
+
+sub die {
+}
+
+sub interrupt {
+	print "Got INT\n";
+}
+sub shutdown {
+}
 
 
 1;
